/***************************************************************************
    copyright            : (C) 2004 - 2005 by 
    email                : mszpyrka@agh.edu.pl
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef _SVG_POLGON
#define _SVG_POLGON

#include <qstring.h>
#include "SVGElement.h"

#include <qvaluevector.h>

namespace SVGOutput
{

/**
  Represents 'polygon' element of SVG Document.
 
  The 'polygon' element defines a closed shape consisting 
  of a set of connected straight line segments.
  Used to render an arrow head.
 */
class SVGPolygon : public SVGElement
{
	/** Stores point data. */
	struct point 
	{ 
	    int x; int y; 	

	    point(): x(0), y(0) { }	    
	    point(int x, int y): x(x), y(y) { }
	};
	
	QValueVector<point> points;

	QString toString(point p)
	{
	    return QString("%1,%2").arg(p.x).arg(p.y);
	}
	
	void validate() { }
	
public:
	/** Creates empty polygon shape. */
	SVGPolygon(){}

	XMLTag *next()
	{
		if(initialized)
		{
			validate();

			XMLTag *tag = SVGElement::next();
			tag->setName("polygon");
			
			tag->removeAttribute("x");
			tag->removeAttribute("y");

			QString path;
			
			QValueVector<point>::iterator it = points.begin();
			while(it != points.end())
			{
			    path += toString(*it);
			    path += " ";
			    
			    it++;
			}
			
			tag->addAttribute("points", path);

			return tag;
		}
		else
			return NULL;
	}
	
	/** Adds new point. */
	void insertPoint(int x, int y)
	{
	    points.push_back(point(x, y));
	}
};

} // end of namespace SVGOutput

#endif // _SVG_RECTANGLE
