/***************************************************************************
    copyright            : (C) 2004 - 2005 by 
    email                : mszpyrka@agh.edu.pl
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include "XMLTextWriter.h"

namespace SVGOutput
{

QTextStream &operator<<(QTextStream &out, const iomanip &io)
{
	// Make 'io' manipulator perform it's work
	return io.output(out);
}

void XMLTextWriter::write(QTextStream &out)
{
    // Initialize stream
    in.init();
    int ind = 0;

    while(in.hasNext())
    {
	// Get next tag in the stream
	XMLTag *tag = in.next();

	switch(tag->getType())
	{
	    // Write tag of the form "</name>"
	    case XMLTag::ttClosing:
		out << indent(--ind) << "</" << name(tag) << ">" << endl;
		break;

	    // Write comment tag: "<!-- comment -->"
    	    case XMLTag::ttComment:
		out << "<!--" << name(tag) << "-->" << endl;
		break;

	    // Write document declaration tag: "<!  >"
	    case XMLTag::ttDocumentType:
		out << indent(ind) << "<!" << name(tag) << ">" << endl;
		break;

	    // Write out self-containing element: <name attr="" ... />
	    case XMLTag::ttElement:
		out << indent(ind) << "<" << name(tag) <<
		    attributes(tag) << "/>" << endl;
		break;

	    // Write out xml processing instruction
	    case XMLTag::ttInstruction:
		out << indent(ind) << "<?" << name(tag) <<
		    attributes(tag) << "?>" << endl;
		break;

	    // Write tag of the form "<name>"
	    case XMLTag::ttOpening:
		out << indent(ind++) << "<" << name(tag) <<
		    attributes(tag) << ">" << endl;
		break;

	    // Write plain text
	    case XMLTag::ttText:
		out << indent(ind) << escaped_name(tag) << endl;
		break;
	}
    }
}

} // end of namespace SVGOutput
